package cn.com.infosec.asn1.isismtt.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.DERPrintableString;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.x500.DirectoryString;
import java.util.Enumeration;

public class ProfessionInfo extends ASN1Encodable {
   public static final DERObjectIdentifier Rechtsanwltin;
   public static final DERObjectIdentifier Rechtsanwalt;
   public static final DERObjectIdentifier Rechtsbeistand;
   public static final DERObjectIdentifier Steuerberaterin;
   public static final DERObjectIdentifier Steuerberater;
   public static final DERObjectIdentifier Steuerbevollmchtigte;
   public static final DERObjectIdentifier Steuerbevollmchtigter;
   public static final DERObjectIdentifier Notarin;
   public static final DERObjectIdentifier Notar;
   public static final DERObjectIdentifier Notarvertreterin;
   public static final DERObjectIdentifier Notarvertreter;
   public static final DERObjectIdentifier Notariatsverwalterin;
   public static final DERObjectIdentifier Notariatsverwalter;
   public static final DERObjectIdentifier Wirtschaftsprferin;
   public static final DERObjectIdentifier Wirtschaftsprfer;
   public static final DERObjectIdentifier VereidigteBuchprferin;
   public static final DERObjectIdentifier VereidigterBuchprfer;
   public static final DERObjectIdentifier Patentanwltin;
   public static final DERObjectIdentifier Patentanwalt;
   private NamingAuthority namingAuthority;
   private ASN1Sequence professionItems;
   private ASN1Sequence professionOIDs;
   private String registrationNumber;
   private ASN1OctetString addProfessionInfo;

   static {
      DERObjectIdentifier var0;
      Rechtsanwltin = new DERObjectIdentifier((var0 = NamingAuthority.id_isismtt_at_namingAuthorities_RechtWirtschaftSteuern) + ".1");
      Rechtsanwalt = new DERObjectIdentifier(var0 + ".2");
      Rechtsbeistand = new DERObjectIdentifier(var0 + ".3");
      Steuerberaterin = new DERObjectIdentifier(var0 + ".4");
      Steuerberater = new DERObjectIdentifier(var0 + ".5");
      Steuerbevollmchtigte = new DERObjectIdentifier(var0 + ".6");
      Steuerbevollmchtigter = new DERObjectIdentifier(var0 + ".7");
      Notarin = new DERObjectIdentifier(var0 + ".8");
      Notar = new DERObjectIdentifier(var0 + ".9");
      Notarvertreterin = new DERObjectIdentifier(var0 + ".10");
      Notarvertreter = new DERObjectIdentifier(var0 + ".11");
      Notariatsverwalterin = new DERObjectIdentifier(var0 + ".12");
      Notariatsverwalter = new DERObjectIdentifier(var0 + ".13");
      Wirtschaftsprferin = new DERObjectIdentifier(var0 + ".14");
      Wirtschaftsprfer = new DERObjectIdentifier(var0 + ".15");
      VereidigteBuchprferin = new DERObjectIdentifier(var0 + ".16");
      VereidigterBuchprfer = new DERObjectIdentifier(var0 + ".17");
      Patentanwltin = new DERObjectIdentifier(var0 + ".18");
      Patentanwalt = new DERObjectIdentifier(var0 + ".19");
   }

   public static ProfessionInfo getInstance(Object obj) {
      if (obj != null && !(obj instanceof ProfessionInfo)) {
         if (obj instanceof ASN1Sequence) {
            return new ProfessionInfo((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("illegal object in getInstance: " + obj.getClass().getName());
         }
      } else {
         return (ProfessionInfo)obj;
      }
   }

   private ProfessionInfo(ASN1Sequence seq) {
      if (seq.size() <= 5) {
         DEREncodable var2;
         Enumeration seq1;
         if ((var2 = (DEREncodable)(seq1 = seq.getObjects()).nextElement()) instanceof ASN1TaggedObject) {
            ASN1TaggedObject var5;
            if ((var5 = (ASN1TaggedObject)var2).getTagNo() != 0) {
               throw new IllegalArgumentException("Bad tag number: " + var5.getTagNo());
            }

            this.namingAuthority = NamingAuthority.getInstance(var5, true);
            var2 = (DEREncodable)seq1.nextElement();
         }

         this.professionItems = ASN1Sequence.getInstance(var2);
         if (seq1.hasMoreElements()) {
            if ((var2 = (DEREncodable)seq1.nextElement()) instanceof ASN1Sequence) {
               this.professionOIDs = ASN1Sequence.getInstance(var2);
            } else if (var2 instanceof DERPrintableString) {
               this.registrationNumber = DERPrintableString.getInstance(var2).getString();
            } else {
               if (!(var2 instanceof ASN1OctetString)) {
                  throw new IllegalArgumentException("Bad object encountered: " + var2.getClass());
               }

               this.addProfessionInfo = ASN1OctetString.getInstance(var2);
            }
         }

         if (seq1.hasMoreElements()) {
            if ((var2 = (DEREncodable)seq1.nextElement()) instanceof DERPrintableString) {
               this.registrationNumber = DERPrintableString.getInstance(var2).getString();
            } else {
               if (!(var2 instanceof DEROctetString)) {
                  throw new IllegalArgumentException("Bad object encountered: " + var2.getClass());
               }

               this.addProfessionInfo = (DEROctetString)var2;
            }
         }

         if (seq1.hasMoreElements()) {
            DEREncodable seq2;
            if (!((seq2 = (DEREncodable)seq1.nextElement()) instanceof DEROctetString)) {
               throw new IllegalArgumentException("Bad object encountered: " + seq2.getClass());
            }

            this.addProfessionInfo = (DEROctetString)seq2;
         }

      } else {
         throw new IllegalArgumentException("Bad sequence size: " + seq.size());
      }
   }

   public ProfessionInfo(NamingAuthority namingAuthority, DirectoryString[] professionItems, DERObjectIdentifier[] professionOIDs, String registrationNumber, ASN1OctetString addProfessionInfo) {
      this.namingAuthority = namingAuthority;
      ASN1EncodableVector namingAuthority1;
      namingAuthority1 = new ASN1EncodableVector.<init>();

      for(int var6 = 0; var6 != professionItems.length; ++var6) {
         namingAuthority1.add(professionItems[var6]);
      }

      DERSequence professionItems1;
      professionItems1 = new DERSequence.<init>(namingAuthority1);
      this.professionItems = professionItems1;
      if (professionOIDs != null) {
         namingAuthority1 = new ASN1EncodableVector.<init>();

         for(int professionItems2 = 0; professionItems2 != professionOIDs.length; ++professionItems2) {
            namingAuthority1.add(professionOIDs[professionItems2]);
         }

         professionItems1 = new DERSequence.<init>(namingAuthority1);
         this.professionOIDs = professionItems1;
      }

      this.registrationNumber = registrationNumber;
      this.addProfessionInfo = addProfessionInfo;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      NamingAuthority var2;
      if ((var2 = this.namingAuthority) != null) {
         DERTaggedObject var3;
         var3 = new DERTaggedObject.<init>(true, 0, var2);
         var1.add(var3);
      }

      var1.add(this.professionItems);
      ASN1Sequence var5;
      if ((var5 = this.professionOIDs) != null) {
         var1.add(var5);
      }

      String var6;
      if ((var6 = this.registrationNumber) != null) {
         DERPrintableString var7;
         var7 = new DERPrintableString.<init>(var6, true);
         var1.add(var7);
      }

      ASN1OctetString var4;
      if ((var4 = this.addProfessionInfo) != null) {
         var1.add(var4);
      }

      return new DERSequence(var1);
   }

   public ASN1OctetString getAddProfessionInfo() {
      return this.addProfessionInfo;
   }

   public NamingAuthority getNamingAuthority() {
      return this.namingAuthority;
   }

   public DirectoryString[] getProfessionItems() {
      DirectoryString[] var3 = new DirectoryString[this.professionItems.size()];
      int var1 = 0;

      for(Enumeration var2 = this.professionItems.getObjects(); var2.hasMoreElements(); var3[var1++] = DirectoryString.getInstance(var2.nextElement())) {
      }

      return var3;
   }

   public DERObjectIdentifier[] getProfessionOIDs() {
      ASN1Sequence var1;
      if ((var1 = this.professionOIDs) == null) {
         return new DERObjectIdentifier[0];
      } else {
         DERObjectIdentifier[] var3 = new DERObjectIdentifier[var1.size()];
         int var4 = 0;

         for(Enumeration var2 = this.professionOIDs.getObjects(); var2.hasMoreElements(); var3[var4++] = DERObjectIdentifier.getInstance(var2.nextElement())) {
         }

         return var3;
      }
   }

   public String getRegistrationNumber() {
      return this.registrationNumber;
   }
}
